@@ -696,15 +696,15 @@ void curve_init_singular_with_node(curve_ptr c, field_t field)
 int element_to_bytes_compressed(unsigned char *data, element_ptr e)
     //e must be a point on an elliptic curve
 {
-    point_t Q;
     point_ptr P = e->data;
-    point_init(Q, P->curve);
     int len;
     len = element_to_bytes(data, P->x);
-    point_from_x(Q, P->x);
-    data[len] = element_cmp(P->y, Q->y);
+    if (element_sign(P->y) > 0) {
+	data[len] = 1;
+    } else {
+	data[len] = 0;
+    }
     len++;
-    point_clear(Q);
     return len;
 }
 
@@ -715,7 +715,10 @@ int element_from_bytes_compressed(element_ptr e, unsigned char *data)
     int len;
     len = element_from_bytes(P->x, data);
     point_from_x(P, P->x);
+
     if (data[len]) {
+	if (element_sign(P->y) < 0) element_neg(P->y, P->y);
+    } else if (element_sign(P->y) > 0) {
 	element_neg(P->y, P->y);
     }
     len++;
