@@ -31,8 +31,8 @@ void e_param_clear(e_param_t ep)
 
 void e_param_gen(e_param_t p, int rbits, int qbits)
 {
-    //28 takes 5-bits to represent
-    int hbits = (qbits - 5) / 2 - rbits;
+    //3 takes 2 bits to represent
+    int hbits = (qbits - 2) / 2 - rbits;
     mpz_ptr q = p->q;
     mpz_ptr r = p->r;
     mpz_ptr h = p->h;
@@ -82,7 +82,7 @@ void e_param_gen(e_param_t p, int rbits, int qbits)
 	    mpz_setbit(q, hbits + 1);
 	    pbc_mpz_random(h, q);
 	    mpz_mul(h, h, h);
-	    mpz_mul_ui(h, h, 28);
+	    mpz_mul_ui(h, h, 3);
 	    //finally q takes the value it should
 	    mpz_mul(n, r, r);
 	    mpz_mul(n, n, h);
@@ -100,16 +100,22 @@ void e_param_gen(e_param_t p, int rbits, int qbits)
 	pbc_mpz_random(r, r);
 	mpz_nextprime(r, r);
 	mpz_mul(n, r, r);
-	mpz_mul_ui(n, n, 28);
+	mpz_mul_ui(n, n, 3);
 	mpz_add_ui(q, n, 1);
     } while (!mpz_probab_prime_p(q, 10));
     */
 
     field_init_fp(Fq, q);
+    /*
     element_init(j, Fq);
     element_set_si(j, -3375);
     curve_init_cc_j(cc, j);
     element_clear(j);
+    */
+    element_init(j, Fq);
+    element_set_si(j, 1);
+    curve_init_b(cc, j);
+    element_clear(j);
 
     //we may need to twist it however
     {
@@ -570,6 +576,12 @@ static void e_pairing(element_ptr out, element_ptr in1, element_ptr in2,
     point_clear(QR);
 }
 
+static void phi_identity(element_ptr out, element_ptr in, pairing_ptr pairing)
+{
+    (void) pairing;
+    element_set(out, in);
+}
+
 void pairing_init_e_param(pairing_t pairing, e_param_t param)
 {
     e_pairing_data_ptr p;
@@ -579,7 +591,6 @@ void pairing_init_e_param(pairing_t pairing, e_param_t param)
     mpz_set(pairing->r, param->r);
     field_init_fp(pairing->Zr, pairing->r);
     pairing->map = e_pairing;
-    pairing->is_almost_coddh = generic_is_almost_coddh;
 
     p =	pairing->data = malloc(sizeof(e_pairing_data_t));
     p->exp2 = param->exp2;
@@ -602,7 +613,7 @@ void pairing_init_e_param(pairing_t pairing, e_param_t param)
 
     field_init_curve_group(pairing->G1, p->Eq, param->h);
     pairing->GT = p->Fq;
-    //pairing->phi = trace;
+    pairing->phi = phi_identity;
 
     element_clear(a);
     element_clear(b);
@@ -757,7 +768,6 @@ void pairing_init_singular_with_node(pairing_t pairing, mpz_t q)
     mpz_sub_ui(pairing->r, q, 1);
     field_init_fp(pairing->Zr, pairing->r);
     pairing->map = sn_pairing;
-    pairing->is_almost_coddh = generic_is_almost_coddh;
 
     p =	pairing->data = malloc(sizeof(e_pairing_data_t));
     field_init_fp(p->Fq, q);
